SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)
Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af
This commit is contained in:
committed by
GitHub
parent
84c23e2b41
commit
2667f3e225
@@ -75,7 +75,7 @@ bool p_atomicNoRet = false;
|
||||
|
||||
template <typename T>
|
||||
__global__ void atomicnoret_manywaves(T* C_d) {
|
||||
size_t tid = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x);
|
||||
size_t tid = (blockIdx.x * blockDim.x + threadIdx.x);
|
||||
switch (tid % 9) {
|
||||
case 0:
|
||||
atomicAddNoRet(C_d, INCREMENT_VALUE);
|
||||
|
||||
Reference in New Issue
Block a user